@@ -32,10 +32,6 @@ class SimpleReadOnlyNovaClientTest(base.ClientTestBase):
 
     # NOTE(jogo): Commands in order listed in 'nova help'
 
-    def test_admin_absolute_limites(self):
-        self.nova('absolute-limits')
-        self.nova('absolute-limits', params='--reserved')
-
     def test_admin_aggregate_list(self):
         self.nova('aggregate-list')
 
@@ -45,22 +41,6 @@ class SimpleReadOnlyNovaClientTest(base.ClientTestBase):
     def test_admin_cloudpipe_list(self):
         self.nova('cloudpipe-list')
 
-    def test_admin_credentials(self):
-        self.nova('credentials')
-
-    # "Neutron does not provide this feature"
-    def test_admin_dns_domains(self):
-        self.skip_if_neutron()
-        self.nova('dns-domains')
-
-    @decorators.skip_because(bug="1157349")
-    def test_admin_dns_list(self):
-        self.skip_if_neutron()
-        self.nova('dns-list')
-
-    def test_admin_endpoints(self):
-        self.nova('endpoints')
-
     def test_admin_flavor_acces_list(self):
         self.assertRaises(exceptions.CommandFailed,
                           self.nova,
@@ -74,25 +54,12 @@ class SimpleReadOnlyNovaClientTest(base.ClientTestBase):
     def test_admin_flavor_list(self):
         self.assertIn("Memory_MB", self.nova('flavor-list'))
 
-    def test_admin_floating_ip_bulk_list(self):
-        self.nova('floating-ip-bulk-list')
-
-    def test_admin_floating_ip_list(self):
-        self.nova('floating-ip-list')
-
-    def test_admin_floating_ip_pool_list(self):
-        self.nova('floating-ip-pool-list')
-
     def test_admin_host_list(self):
         self.nova('host-list')
 
     def test_admin_hypervisor_list(self):
         self.nova('hypervisor-list')
 
-    def test_admin_image_list(self):
-        out = self.nova('image-list', merge_stderr=True)
-        self.assertIn('Command image-list is deprecated', out)
-
     @decorators.skip_because(bug="1157349")
     def test_admin_interface_list(self):
         self.nova('interface-list')
@@ -109,19 +76,6 @@ class SimpleReadOnlyNovaClientTest(base.ClientTestBase):
                           'list',
                           params='--all-tenants bad')
 
-    def test_admin_network_list(self):
-        self.nova('network-list')
-
-    def test_admin_rate_limits(self):
-        self.nova('rate-limits')
-
-    def test_admin_secgroup_list(self):
-        self.nova('secgroup-list')
-
-    @decorators.skip_because(bug="1157349")
-    def test_admin_secgroup_list_rules(self):
-        self.nova('secgroup-list-rules')
-
     def test_admin_server_group_list(self):
         self.nova('server-group-list')
 
@@ -140,9 +94,6 @@ class SimpleReadOnlyNovaClientTest(base.ClientTestBase):
     def test_admin_list_extensions(self):
         self.nova('list-extensions')
 
-    def test_admin_net_list(self):
-        self.nova('net-list')
-
     def test_agent_list(self):
         self.nova('agent-list')
         self.nova('agent-list', flags='--debug')
@@ -179,4 +130,4 @@ class SimpleReadOnlyNovaClientTest(base.ClientTestBase):
         self.assertRaises(exceptions.CommandFailed,
                           self.nova,
                           'list',
-                          flags='--bypass-url badurl')
+                          flags='--endpoint-override badurl')
