@@ -11,9 +11,9 @@
 #    under the License.
 
 import datetime
-import uuid
 
 from oslo_utils import timeutils
+from oslo_utils import uuidutils
 
 from novaclient.tests.functional import base
 
@@ -25,7 +25,7 @@ class TestServersBootNovaClient(base.ClientTestBase):
 
     def _boot_server_with_legacy_bdm(self, bdm_params=()):
         volume_size = 1
-        volume_name = str(uuid.uuid4())
+        volume_name = uuidutils.generate_uuid()
         volume = self.cinder.volumes.create(size=volume_size,
                                             name=volume_name,
                                             imageRef=self.image.id)
@@ -35,13 +35,17 @@ class TestServersBootNovaClient(base.ClientTestBase):
         if bdm_params:
             bdm_params = ''.join((':', bdm_params))
 
-        server_info = self.nova("boot", params=(
+        params = (
             "%(name)s --flavor %(flavor)s --poll "
             "--block-device-mapping vda=%(volume_id)s%(bdm_params)s" % {
-                "name": str(uuid.uuid4()), "flavor":
+                "name": uuidutils.generate_uuid(), "flavor":
                     self.flavor.id,
                 "volume_id": volume.id,
-                "bdm_params": bdm_params}))
+                "bdm_params": bdm_params})
+        # check to see if we have to pass in a network id
+        if self.multiple_networks:
+            params += ' --nic net-id=%s' % self.network.id
+        server_info = self.nova("boot", params=params)
         server_id = self._get_value_from_the_table(server_info, "id")
 
         self.client.servers.delete(server_id)
@@ -60,15 +64,56 @@ class TestServersBootNovaClient(base.ClientTestBase):
     def test_boot_server_with_net_name(self):
         server_info = self.nova("boot", params=(
             "%(name)s --flavor %(flavor)s --image %(image)s --poll "
-            "--nic net-name=%(net-name)s" % {"name": str(uuid.uuid4()),
+            "--nic net-name=%(net-name)s" % {"name": uuidutils.generate_uuid(),
                                              "image": self.image.id,
                                              "flavor": self.flavor.id,
-                                             "net-name": self.network.label}))
+                                             "net-name": self.network.name}))
         server_id = self._get_value_from_the_table(server_info, "id")
 
         self.client.servers.delete(server_id)
         self.wait_for_resource_delete(server_id, self.client.servers)
 
+    def test_boot_server_using_image_with(self):
+        """Scenario test which does the following:
+
+        1. Create a server.
+        2. Create a snapshot image of the server with a special meta key.
+        3. Create a second server using the --image-with option using the meta
+           key stored in the snapshot image created in step 2.
+        """
+        # create the first server and wait for it to be active
+        server_info = self.nova('boot', params=(
+            '--flavor %(flavor)s --image %(image)s --poll '
+            'image-with-server-1' % {'image': self.image.id,
+                                     'flavor': self.flavor.id}))
+        server_id = self._get_value_from_the_table(server_info, 'id')
+        self.addCleanup(self._cleanup_server, server_id)
+
+        # create a snapshot of the server with an image metadata key
+        snapshot_info = self.nova('image-create', params=(
+            '--metadata image_with_meta=%(meta_value)s '
+            '--show --poll %(server_id)s image-with-snapshot' % {
+                'meta_value': server_id,
+                'server_id': server_id}))
+
+        # get the snapshot image id out of the output table for the second
+        # server create request
+        snapshot_id = self._get_value_from_the_table(snapshot_info, 'id')
+        self.addCleanup(self.glance.images.delete, snapshot_id)
+
+        # verify the metadata was set on the snapshot image
+        meta_value = self._get_value_from_the_table(
+            snapshot_info, 'image_with_meta')
+        self.assertEqual(server_id, meta_value)
+
+        # create the second server using --image-with
+        server_info = self.nova('boot', params=(
+            '--flavor %(flavor)s --image-with image_with_meta=%(meta_value)s '
+            '--poll image-with-server-2' % {'meta_value': server_id,
+                                            'flavor': self.flavor.id}))
+        server_id = self._get_value_from_the_table(server_info, 'id')
+        self.addCleanup(self._cleanup_server, server_id)
+
 
 class TestServersListNovaClient(base.ClientTestBase):
     """Servers list functional tests."""
@@ -79,7 +124,7 @@ class TestServersListNovaClient(base.ClientTestBase):
         return [self._create_server(name) for i in range(number)]
 
     def test_list_with_limit(self):
-        name = str(uuid.uuid4())
+        name = uuidutils.generate_uuid()
         self._create_servers(name, 2)
         output = self.nova("list", params="--limit 1 --name %s" % name)
         # Cut header and footer of the table
@@ -88,7 +133,7 @@ class TestServersListNovaClient(base.ClientTestBase):
 
     def test_list_with_changes_since(self):
         now = datetime.datetime.isoformat(timeutils.utcnow())
-        name = str(uuid.uuid4())
+        name = uuidutils.generate_uuid()
         self._create_servers(name, 1)
         output = self.nova("list", params="--changes-since %s" % now)
         self.assertIn(name, output, output)
@@ -97,7 +142,7 @@ class TestServersListNovaClient(base.ClientTestBase):
         self.assertNotIn(name, output, output)
 
     def test_list_all_servers(self):
-        name = str(uuid.uuid4())
+        name = uuidutils.generate_uuid()
         precreated_servers = self._create_servers(name, 3)
         # there are no possibility to exceed the limit on API side, so just
         # check that "-1" limit processes by novaclient side
