@@ -173,7 +173,7 @@ class DeprecatedActionTest(utils.TestCase):
 
         self.assertEqual(result.emitted, set())
         self.assertIsNone(result.use)
-        self.assertEqual(result.real_action_args, False)
+        self.assertIs(result.real_action_args, False)
         self.assertIsNone(result.real_action)
         mock_init.assert_called_once_with(
             'option_strings', 'dest', help='Deprecated', a=1, b=2, c=3)
@@ -200,7 +200,7 @@ class DeprecatedActionTest(utils.TestCase):
 
         self.assertEqual(result.emitted, set())
         self.assertIsNone(result.use)
-        self.assertEqual(result.real_action_args, False)
+        self.assertIs(result.real_action_args, False)
         self.assertEqual(result.real_action, action.return_value)
         mock_init.assert_called_once_with(
             'option_strings', 'dest', help='Deprecated', a=1, b=2, c=3)
@@ -459,8 +459,8 @@ class ShellTest(utils.TestCase):
             '.*--matching',
             '.*--wrap',
             '.*help',
-            '.*secgroup-delete-rule',
-            '.*--priority']
+            '.*server-group-delete',
+            '.*--image-with']
         for r in required:
             self.assertThat((stdout + stderr),
                             matchers.MatchesRegex(r, re.DOTALL | re.MULTILINE))
@@ -655,6 +655,27 @@ class ShellTest(utils.TestCase):
         exc = self.assertRaises(RuntimeError, self.shell, '--timings list')
         self.assertEqual('Boom!', str(exc))
 
+    @requests_mock.Mocker()
+    def test_osprofiler(self, m_requests):
+        self.make_env()
+
+        def client(*args, **kwargs):
+            self.assertEqual('swordfish', kwargs['profile'])
+        with mock.patch('novaclient.client.Client', client):
+            # we are only interested in the fact Client is initialized properly
+            self.shell('list --profile swordfish', (0, 2))
+
+    @requests_mock.Mocker()
+    def test_osprofiler_not_installed(self, m_requests):
+        self.make_env()
+
+        # NOTE(rpodolyaka): osprofiler is in test-requirements, so we have to
+        # simulate its absence here
+        with mock.patch('novaclient.shell.osprofiler_profiler', None):
+            _, stderr = self.shell('list --profile swordfish', (0, 2))
+            self.assertIn('unrecognized arguments: --profile swordfish',
+                          stderr)
+
     @mock.patch('novaclient.shell.SecretsHelper.tenant_id',
                 return_value=True)
     @mock.patch('novaclient.shell.SecretsHelper.auth_token',
