@@ -996,114 +996,10 @@ class FakeSessionClient(base_client.SessionClient):
         return (202, FAKE_RESPONSE_HEADERS,
                 self.get_flavors_2_os_flavor_access()[2])
 
-    #
-    # Floating IPs
-    #
-
-    def get_os_floating_ips(self, **kw):
-        return (
-            200,
-            {},
-            {'floating_ips': [
-                {'id': 1, 'fixed_ip': '10.0.0.1', 'ip': '11.0.0.1'},
-                {'id': 2, 'fixed_ip': '10.0.0.2', 'ip': '11.0.0.2'},
-            ]},
-        )
-
-    def get_os_floating_ips_1(self, **kw):
-        return (
-            200, {}, {'floating_ip': {'id': 1, 'fixed_ip': '10.0.0.1',
-                                      'ip': '11.0.0.1'}})
-
-    def post_os_floating_ips(self, body):
-        if body.get('pool'):
-            return (
-                200, {}, {'floating_ip': {'id': 1, 'fixed_ip': '10.0.0.1',
-                                          'ip': '11.0.0.1',
-                                          'pool': 'nova'}})
-        else:
-            return (
-                200, {}, {'floating_ip': {'id': 1, 'fixed_ip': '10.0.0.1',
-                                          'ip': '11.0.0.1',
-                                          'pool': None}})
-
-    def delete_os_floating_ips_1(self, **kw):
-        return (204, {}, None)
-
-    def get_os_floating_ip_dns(self, **kw):
-        return (205, {}, {'domain_entries':
-                          [{'domain': 'example.org'},
-                           {'domain': 'example.com'}]})
-
-    def get_os_floating_ip_dns_testdomain_entries(self, **kw):
-        if kw.get('ip'):
-            return (205, {}, {
-                'dns_entries': [
-                    {'dns_entry': {'ip': kw.get('ip'),
-                                   'name': "host1",
-                                   'type': "A",
-                                   'domain': 'testdomain'}},
-                    {'dns_entry': {'ip': kw.get('ip'),
-                                   'name': "host2",
-                                   'type': "A",
-                                   'domain': 'testdomain'}}]})
-        else:
-            return (404, {}, None)
-
-    def get_os_floating_ip_dns_testdomain_entries_testname(self, **kw):
-        return (205, {}, {
-            'dns_entry': {'ip': "10.10.10.10",
-                          'name': 'testname',
-                          'type': "A",
-                          'domain': 'testdomain'}})
-
-    def put_os_floating_ip_dns_testdomain(self, body, **kw):
-        if body['domain_entry']['scope'] == 'private':
-            fakes.assert_has_keys(body['domain_entry'],
-                                  required=['availability_zone', 'scope'])
-        elif body['domain_entry']['scope'] == 'public':
-            fakes.assert_has_keys(body['domain_entry'],
-                                  required=['project', 'scope'])
-
-        else:
-            fakes.assert_has_keys(body['domain_entry'],
-                                  required=['project', 'scope'])
-        return (205, {}, body)
-
-    def put_os_floating_ip_dns_testdomain_entries_testname(self, body, **kw):
-        fakes.assert_has_keys(body['dns_entry'],
-                              required=['ip', 'dns_type'])
-        return (205, {}, body)
-
-    def delete_os_floating_ip_dns_testdomain(self, **kw):
-        return (200, {}, None)
-
-    def delete_os_floating_ip_dns_testdomain_entries_testname(self, **kw):
-        return (200, {}, None)
-
-    def get_os_floating_ips_bulk(self, **kw):
-        return (200, {}, {'floating_ip_info': [
-            {'id': 1, 'fixed_ip': '10.0.0.1', 'ip': '11.0.0.1'},
-            {'id': 2, 'fixed_ip': '10.0.0.2', 'ip': '11.0.0.2'},
-        ]})
-
-    def post_os_floating_ips_bulk(self, **kw):
-        params = kw.get('body').get('floating_ips_bulk_create')
-        pool = params.get('pool', 'defaultPool')
-        interface = params.get('interface', 'defaultInterface')
-        return (200, {}, {'floating_ips_bulk_create':
-                          {'ip_range': '192.168.1.0/30',
-                           'pool': pool,
-                           'interface': interface}})
-
-    def put_os_floating_ips_bulk_delete(self, **kw):
-        ip_range = kw.get('body').get('ip_range')
-        return (200, {}, {'floating_ips_bulk_delete': ip_range})
-
     #
     # Images
     #
-    def get_images_detail(self, **kw):
+    def get_images(self, **kw):
         return (200, {}, {'images': [
             {
                 "id": FAKE_IMAGE_UUID_SNAPSHOT,
@@ -1131,9 +1027,7 @@ class FakeSessionClient(base_client.SessionClient):
                 "updated": "2010-10-10T12:00:00Z",
                 "created": "2010-08-10T12:00:00Z",
                 "status": "ACTIVE",
-                "metadata": {
-                    "test_key": "test_value",
-                },
+                "test_key": "test_value",
                 "links": {},
             },
             {
@@ -1149,41 +1043,20 @@ class FakeSessionClient(base_client.SessionClient):
         ]})
 
     def get_images_555cae93_fb41_4145_9c52_f5b923538a26(self, **kw):
-        return (200, {}, {'image': self.get_images_detail()[2]['images'][0]})
+        return (200, {}, {'image': self.get_images()[2]['images'][0]})
 
     def get_images_55bb23af_97a4_4068_bdf8_f10c62880ddf(self, **kw):
-        return (200, {}, {'image': self.get_images_detail()[2]['images'][1]})
+        return (200, {}, {'image': self.get_images()[2]['images'][1]})
 
     def get_images_c99d7632_bd66_4be9_aed5_3dd14b223a76(self, **kw):
-        return (200, {}, {'image': self.get_images_detail()[2]['images'][2]})
+        return (200, {}, {'image': self.get_images()[2]['images'][2]})
 
     def get_images_f27f479a_ddda_419a_9bbc_d6b56b210161(self, **kw):
-        return (200, {}, {'image': self.get_images_detail()[2]['images'][3]})
+        return (200, {}, {'image': self.get_images()[2]['images'][3]})
 
     def get_images_3e861307_73a6_4d1f_8d68_f68b03223032(self):
         raise exceptions.NotFound('404')
 
-    def post_images_c99d7632_bd66_4be9_aed5_3dd14b223a76_metadata(
-            self, body, **kw):
-        assert list(body) == ['metadata']
-        fakes.assert_has_keys(body['metadata'],
-                              required=['test_key'])
-        get_image = self.get_images_c99d7632_bd66_4be9_aed5_3dd14b223a76
-        return (
-            200,
-            {},
-            {'metadata': get_image()[2]['image']['metadata']})
-
-    def delete_images_c99d7632_bd66_4be9_aed5_3dd14b223a76(self, **kw):
-        return (204, {}, None)
-
-    def delete_images_f27f479a_ddda_419a_9bbc_d6b56b210161(self, **kw):
-        return (204, {}, None)
-
-    def delete_images_c99d7632_bd66_4be9_aed5_3dd14b223a76_metadata_test_key(
-            self, **kw):
-        return (204, {}, None)
-
     #
     # Keypairs
     #
@@ -1442,105 +1315,6 @@ class FakeSessionClient(base_client.SessionClient):
                 'security_groups': 1,
                 'security_group_rules': 1}})
 
-    #
-    # Security Groups
-    #
-    def get_os_security_groups(self, **kw):
-        return (200, {}, {"security_groups": [
-            {"name": "test",
-             "description": "FAKE_SECURITY_GROUP",
-             "tenant_id": "4ffc664c198e435e9853f2538fbcd7a7",
-             "id": 1,
-             "rules": [
-                 {"id": 11,
-                  "group": {},
-                  "ip_protocol": "TCP",
-                  "from_port": 22,
-                  "to_port": 22,
-                  "parent_group_id": 1,
-                  "ip_range":
-                      {"cidr": "10.0.0.0/8"}},
-                 {"id": 12,
-                  "group": {
-                      "tenant_id":
-                          "272bee4c1e624cd4a72a6b0ea55b4582",
-                      "name": "test2"},
-
-                  "ip_protocol": "TCP",
-                  "from_port": 222,
-                  "to_port": 222,
-                  "parent_group_id": 1,
-                  "ip_range": {}},
-                 {"id": 14,
-                  "group": {
-                      "tenant_id":
-                          "272bee4c1e624cd4a72a6b0ea55b4582",
-                      "name": "test4"},
-
-                  "ip_protocol": "TCP",
-                  "from_port": -1,
-                  "to_port": -1,
-                  "parent_group_id": 1,
-                  "ip_range": {}}]},
-            {"name": "test2",
-             "description": "FAKE_SECURITY_GROUP2",
-             "tenant_id": "272bee4c1e624cd4a72a6b0ea55b4582",
-             "id": 2,
-             "rules": []},
-            {"name": "test4",
-             "description": "FAKE_SECURITY_GROUP4",
-             "tenant_id": "272bee4c1e624cd4a72a6b0ea55b4582",
-             "id": 4,
-             "rules": []}
-        ]})
-
-    def delete_os_security_groups_1(self, **kw):
-        return (202, {}, None)
-
-    def post_os_security_groups(self, body, **kw):
-        assert list(body) == ['security_group']
-        fakes.assert_has_keys(body['security_group'],
-                              required=['name', 'description'])
-        r = {'security_group':
-             self.get_os_security_groups()[2]['security_groups'][0]}
-        return (202, {}, r)
-
-    def put_os_security_groups_1(self, body, **kw):
-        assert list(body) == ['security_group']
-        fakes.assert_has_keys(body['security_group'],
-                              required=['name', 'description'])
-        return (205, {}, body)
-
-    #
-    # Security Group Rules
-    #
-    def get_os_security_group_rules(self, **kw):
-        return (200, {}, {"security_group_rules": [
-            {'id': 1, 'parent_group_id': 1, 'group_id': 2,
-             'ip_protocol': 'TCP', 'from_port': 22, 'to_port': 22,
-             'cidr': '10.0.0.0/8'}
-        ]})
-
-    def delete_os_security_group_rules_11(self, **kw):
-        return (202, {}, None)
-
-    def delete_os_security_group_rules_12(self, **kw):
-        return (202, {}, None)
-
-    def delete_os_security_group_rules_14(self, **kw):
-        return (202, {}, None)
-
-    def post_os_security_group_rules(self, body, **kw):
-        assert list(body) == ['security_group_rule']
-        fakes.assert_has_keys(
-            body['security_group_rule'],
-            required=['parent_group_id'],
-            optional=['group_id', 'ip_protocol', 'from_port',
-                      'to_port', 'cidr'])
-        r = {'security_group_rule':
-             self.get_os_security_group_rules()[2]['security_group_rules'][0]}
-        return (202, {}, r)
-
     #
     # Tenant Usage
     #
@@ -1802,18 +1576,6 @@ class FakeSessionClient(base_client.SessionClient):
             'binary': body['binary'],
             'forced_down': False}})
 
-    #
-    # Fixed IPs
-    #
-    def get_os_fixed_ips_192_168_1_1(self, *kw):
-        return (200, {}, {"fixed_ip": {'cidr': '192.168.1.0/24',
-                                       'address': '192.168.1.1',
-                                       'hostname': 'foo',
-                                       'host': 'bar'}})
-
-    def post_os_fixed_ips_192_168_1_1_action(self, body, **kw):
-        return (202, {}, None)
-
     #
     # Hosts
     #
@@ -2019,44 +1781,6 @@ class FakeSessionClient(base_client.SessionClient):
 
         return (200, {}, {"networks": networks_by_name[name]})
 
-    def get_os_networks(self, **kw):
-        return (200, {}, {'networks': [{"label": "1", "cidr": "10.0.0.0/24",
-                                        'project_id':
-                                            '4ffc664c198e435e9853f2538fbcd7a7',
-                                        'id': '1', 'vlan': '1234'}]})
-
-    def delete_os_networks_1(self, **kw):
-        return (202, {}, None)
-
-    def post_os_networks(self, **kw):
-        return (202, {}, {'network': kw})
-
-    def post_os_networks_add(self, **kw):
-        return (202, {}, None)
-
-    def post_os_networks_1_action(self, **kw):
-        return (202, {}, None)
-
-    def post_os_networks_2_action(self, **kw):
-        return (202, {}, None)
-
-    def get_os_tenant_networks(self, **kw):
-        return (200, {}, {'networks': [{"label": "1", "cidr": "10.0.0.0/24",
-                                        'project_id':
-                                            '4ffc664c198e435e9853f2538fbcd7a7',
-                                        'id': '1', 'vlan': '1234'}]})
-
-    def get_os_tenant_networks_1(self, **kw):
-        return (200, {}, {'network': {"label": "1", "cidr": "10.0.0.0/24",
-                                      "id": "1"}})
-
-    def post_os_tenant_networks(self, **kw):
-        return (202, {}, {'network': {"label": "new_network1",
-                                      "cidr1": "10.0.1.0/24"}})
-
-    def delete_os_tenant_networks_1(self, **kw):
-        return (202, {}, None)
-
     def get_os_availability_zone_detail(self, **kw):
         return (200, {}, {
             "availabilityZoneInfo": [
@@ -2369,71 +2093,6 @@ class FakeSessionClient(base_client.SessionClient):
     def delete_servers_1234_tags(self, **kw):
         return (204, {}, None)
 
-    def get_os_tenant_networks(self):
-        return (200, FAKE_RESPONSE_HEADERS, {
-            'networks': [{"label": "1", "cidr": "10.0.0.0/24",
-                          'project_id': '4ffc664c198e435e9853f2538fbcd7a7',
-                          'id': '1'}]})
-
-    def get_os_tenant_networks_1(self, **kw):
-        return (200, FAKE_RESPONSE_HEADERS, {
-            'network': {"label": "1", "cidr": "10.0.0.0/24",
-                        'project_id': '4ffc664c198e435e9853f2538fbcd7a7',
-                        'id': '1'}})
-
-    def post_os_tenant_networks(self, **kw):
-        return (201, FAKE_RESPONSE_HEADERS, {
-            'network': {"label": "1", "cidr": "10.0.0.0/24",
-                        'project_id': '4ffc664c198e435e9853f2538fbcd7a7',
-                        'id': '1'}})
-
-    def delete_os_tenant_networks_1(self, **kw):
-        return (204, FAKE_RESPONSE_HEADERS, None)
-
-    def get_os_baremetal_nodes(self, **kw):
-        return (
-            200, FAKE_RESPONSE_HEADERS, {
-                'nodes': [
-                    {
-                        "id": 1,
-                        "instance_uuid": None,
-                        "interfaces": [],
-                        "cpus": 2,
-                        "local_gb": 10,
-                        "memory_mb": 5,
-                        "pm_address": "2.3.4.5",
-                        "pm_user": "pmuser",
-                        "pm_password": "pmpass",
-                        "prov_mac_address": "aa:bb:cc:dd:ee:ff",
-                        "prov_vlan_id": 1,
-                        "service_host": "somehost",
-                        "terminal_port": 8080,
-                    }
-                ]
-            }
-        )
-
-    def get_os_baremetal_nodes_1(self, **kw):
-        return (
-            200, FAKE_RESPONSE_HEADERS, {
-                'node': {
-                    "id": 1,
-                    "instance_uuid": None,
-                    "pm_address": "1.2.3.4",
-                    "interfaces": [],
-                    "cpus": 2,
-                    "local_gb": 10,
-                    "memory_mb": 5,
-                    "pm_user": "pmuser",
-                    "pm_password": "pmpass",
-                    "prov_mac_address": "aa:bb:cc:dd:ee:ff",
-                    "prov_vlan_id": 1,
-                    "service_host": "somehost",
-                    "terminal_port": 8080,
-                }
-            }
-        )
-
     def post_os_assisted_volume_snapshots(self, **kw):
         return (202, FAKE_RESPONSE_HEADERS,
                 {'snapshot': {'id': 'blah', 'volumeId': '1'}})
