@@ -16,28 +16,14 @@
 External event triggering for servers, not to be used by users.
 """
 
-from novaclient import base
+from novaclient.v2 import contrib
+from novaclient.v2 import server_external_events
 
 
-class Event(base.Resource):
-    def __repr__(self):
-        return "<Event: %s>" % self.name
-
-
-class ServerExternalEventManager(base.Manager):
-    resource_class = Event
-
-    def create(self, events):
-        """Create one or more server events.
-
-        :param:events: A list of dictionaries containing 'server_uuid', 'name',
-                       'status', and 'tag' (which may be absent)
-        """
-
-        body = {'events': events}
-        return self._create('/os-server-external-events', body, 'events',
-                            return_raw=True)
-
+Event = server_external_events.Event
+ServerExternalEventManager = server_external_events.ServerExternalEventManager
 
 manager_class = ServerExternalEventManager
 name = 'server_external_events'
+
+contrib.warn()
